@@ -4,11 +4,14 @@ import (
 	"github.com/urfave/cli/v2"
 )
 
+// Diff is struct for running 'diff' commands.
 type Diff struct {
-	Wide       int
-	ShowSecret bool
+	ThreeWayMerge bool
+	ShowSecret    bool
+	Wide          int
 }
 
+// Cmd returns 'diff' *cli.Command.
 func (d *Diff) Cmd() *cli.Command {
 	plan := DiffLocalPlan{diff: d}
 	live := DiffLive{diff: d}
@@ -25,9 +28,11 @@ func (d *Diff) Cmd() *cli.Command {
 	}
 }
 
+// flags return flag set of CLI urfave.
 func (d *Diff) flags() []cli.Flag {
 	return []cli.Flag{
 		flagDiffWide(&d.Wide),
 		flagDiffShowSecret(&d.ShowSecret),
+		flagDiffThreeWayMerge(&d.ThreeWayMerge),
 	}
 }
