@@ -8,13 +8,13 @@ import (
 	"helm.sh/helm/v3/pkg/release"
 )
 
-func (rel *Config) List() (*release.Release, error) {
+func (rel *config) List() (*release.Release, error) {
 	client := action.NewList(rel.Cfg())
-	client.Filter = fmt.Sprintf("^%s$", regexp.QuoteMeta(rel.Name))
+	client.Filter = fmt.Sprintf("^%s$", regexp.QuoteMeta(rel.Name()))
 
 	result, err := client.Run()
 	if err != nil {
-		return nil, err
+		return nil, fmt.Errorf("failed to list release %s: %w", rel.Uniq(), err)
 	}
 
 	switch len(result) {
